class puppet_enterprise::profile::master::puppetdb(
  $puppetdb_host,
  $puppetdb_port,
  $soft_write_failure       = false,
) inherits puppet_enterprise::params {

  @@puppet_enterprise::certs::puppetdb_whitelist_entry { "export: ${::clientcert}-for-puppetdb-whitelist":
    certname => $::clientcert,
  }

  $confdir = '/etc/puppetlabs/puppet'

  Pe_ini_setting {
    ensure  => present,
    section => 'main'
  }

  # Start
  # puppetdb.conf
  file { "${confdir}/puppetdb.conf":
    mode    => '0644',
  }

  pe_ini_setting { 'puppetdb.conf_server':
    path    => "${confdir}/puppetdb.conf",
    setting => 'server',
    value   => $puppetdb_host,
  }

  pe_ini_setting { 'puppetdb.conf_port':
    path    => "${confdir}/puppetdb.conf",
    setting => 'port',
    value   => $puppetdb_port,
  }

  pe_ini_setting { 'puppetdb.conf_soft_write_failure':
    path    => "${confdir}/puppetdb.conf",
    setting => 'soft_write_failure',
    value   => $soft_write_failure,
  }
  # End

  # Start
  # puppet.conf
  pe_ini_setting { 'storeconfigs' :
    path    => "${confdir}/puppet.conf",
    section => 'master',
    setting => 'storeconfigs',
    value   => true,
  }

  pe_ini_setting { 'storeconfigs_backend' :
    path    => "${confdir}/puppet.conf",
    section => 'master',
    setting => 'storeconfigs_backend',
    value   => 'puppetdb',
  }

  pe_ini_subsetting { 'reports_puppetdb' :
    ensure               => present,
    path                 => "${confdir}/puppet.conf",
    section              => 'master',
    setting              => 'reports',
    subsetting           => 'puppetdb',
    subsetting_separator => ',',
  }
  # End

  file { "${confdir}/routes.yaml":
    ensure  => present,
    content => template('puppet_enterprise/master/routes.yaml.erb'),
    owner   => 'pe-puppet',
    group   => 'pe-puppet',
    mode    => '0444',
  }
}
